# eigenrules

Powered by [eigendata.ai](https://eigendata.ai)

# installation

`pip install eigenai`

or

`poetry add eigenai`

# usage

please refer to the [examples folder](./examples/) for usage examples
